==> Bibulus-0.14.tar.gz: Bibulus-0.14/Bibulus/ru.pm <==
package Bibulus::ru;

use strict;
use warnings;
use Carp;

# This file is not finished.  Please help!

sub populate {
  my $self = shift;
  $self->{LANGTEXT}{ru}{and} ||= 'и';
  $self->{LANGTEXT}{ru}{etal} ||= 'и др.';
  $self->{LANGTEXT}{ru}{editors}{full} ||= 'редакторы';
  $self->{LANGTEXT}{ru}{editors}{abbr} ||= 'ред.';
  $self->{LANGTEXT}{ru}{editor}{full} ||= 'редактор';
  $self->{LANGTEXT}{ru}{editor}{abbr} ||= 'ред.';
  $self->{LANGTEXT}{ru}{edby} ||= 'под ред.';
  $self->{LANGTEXT}{ru}{edition}{full} ||= 'издание';
  $self->{LANGTEXT}{ru}{edition}{abbr} ||= 'изд.';
  $self->{LANGTEXT}{ru}{volume}{full} ||= 'том';
  $self->{LANGTEXT}{ru}{volume}{abbr} ||= 'т.';
  $self->{LANGTEXT}{ru}{of} ||= 'из';
  $self->{LANGTEXT}{ru}{number}{full} ||= 'номер';
  $self->{LANGTEXT}{ru}{number}{abbr} ||= 'номер';
  $self->{LANGTEXT}{ru}{nr} ||= '№';
  $self->{LANGTEXT}{ru}{in} ||= 'в';
  $self->{LANGTEXT}{ru}{pages}{full} ||= 'страницы';
  $self->{LANGTEXT}{ru}{pages}{abbr} ||= 'с.';
  $self->{LANGTEXT}{ru}{page}{full} ||= 'страница';
  $self->{LANGTEXT}{ru}{page}{abbr} ||= 'с.';
  $self->{LANGTEXT}{ru}{eidpp} ||= 'страницы';
  $self->{LANGTEXT}{ru}{chapter}{full} ||= 'глава';
  $self->{LANGTEXT}{ru}{chapter}{abbr} ||= 'гл.';
  #$self->{LANGTEXT}{ru}{techrep}{full} ||= '???';
  #$self->{LANGTEXT}{ru}{techrep}{abbr} ||= '???';
  $self->{LANGTEXT}{ru}{mthesis} ||= 'магистерская работа';
  $self->{LANGTEXT}{ru}{phdthesis} ||= 'докторская диссертация';
  $self->{LANGTEXT}{ru}{edno}{1}{full} ||= 'первое';
  $self->{LANGTEXT}{ru}{edno}{1}{abbr} ||= '1-ое';
  $self->{LANGTEXT}{ru}{edno}{2}{full} ||= 'второе';
  $self->{LANGTEXT}{ru}{edno}{2}{abbr} ||= '2-ое';
  $self->{LANGTEXT}{ru}{edno}{3}{full} ||= 'третее';
  $self->{LANGTEXT}{ru}{edno}{3}{abbr} ||= '3-ее';
  $self->{LANGTEXT}{ru}{edno}{4}{full} ||= 'четвертое';
  $self->{LANGTEXT}{ru}{edno}{4}{abbr} ||= '4-ое';
  $self->{LANGTEXT}{ru}{edno}{5}{full} ||= 'пятое';
  $self->{LANGTEXT}{ru}{edno}{5}{abbr} ||= '5-ое';
  $self->{LANGTEXT}{ru}{th} ||= '-ое';
  $self->{LANGTEXT}{ru}{month}{1}{full} ||= 'январь';
  $self->{LANGTEXT}{ru}{month}{2}{full} ||= 'февраль';
  $self->{LANGTEXT}{ru}{month}{3}{full} ||= 'март';
  $self->{LANGTEXT}{ru}{month}{4}{full} ||= 'апрель';
  $self->{LANGTEXT}{ru}{month}{5}{full} ||= 'май';
  $self->{LANGTEXT}{ru}{month}{6}{full} ||= 'июнь';
  $self->{LANGTEXT}{ru}{month}{7}{full} ||= 'июль';
  $self->{LANGTEXT}{ru}{month}{8}{full} ||= 'август';
  $self->{LANGTEXT}{ru}{month}{9}{full} ||= 'сентябрь';
  $self->{LANGTEXT}{ru}{month}{10}{full} ||= 'октябрь';
  $self->{LANGTEXT}{ru}{month}{11}{full} ||= 'ноябрь';
  $self->{LANGTEXT}{ru}{month}{12}{full} ||= 'декабрь';
  $self->{LANGTEXT}{ru}{month}{1}{abbr} ||= 'янв.';
  $self->{LANGTEXT}{ru}{month}{2}{abbr} ||= 'февр.';
  $self->{LANGTEXT}{ru}{month}{3}{abbr} ||= 'март';
  $self->{LANGTEXT}{ru}{month}{4}{abbr} ||= 'апр.';
  $self->{LANGTEXT}{ru}{month}{5}{abbr} ||= 'май';
  $self->{LANGTEXT}{ru}{month}{6}{abbr} ||= 'июнь';
  $self->{LANGTEXT}{ru}{month}{7}{abbr} ||= 'июль';
  $self->{LANGTEXT}{ru}{month}{8}{abbr} ||= 'авг.';
  $self->{LANGTEXT}{ru}{month}{9}{abbr} ||= 'сент.'
  $self->{LANGTEXT}{ru}{month}{10}{abbr} ||= 'окт.';
  $self->{LANGTEXT}{ru}{month}{11}{abbr} ||= 'ноябр.';
  $self->{LANGTEXT}{ru}{month}{12}{abbr} ||= 'дек.';

  $self->{LANGINIT}{ru} = 1;
}

1;
__END__

=head1 NAME

Bibulus::Lang::ru - Bibulus support for Russian

=head2 EXPORT

None.

=head1 SEE ALSO

F<Bibulus>, F<Bibulus::lang>.

The homepage is
L<http://www.nongnu.org/bibulus/>.

=head1 AUTHOR

Marius L. Jøhndal, L<mariuslj@cpan.org>

=head1 COPYRIGHT AND LICENSE

Copyright 2003 by Marius L. Jøhndal

This module is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
USA.

=cut

==> Bibulus-0.49.tar.gz: Bibulus-0.49/Bibulus/ru.pm <==
package Bibulus::ru;

use strict;
use warnings;
use Carp;

# This file is not finished.  Please help!

sub populate {
  my $self = shift;

  $self->{LANGTEXT}{ru}{and} ||= 'и';
  $self->{LANGTEXT}{ru}{etal} ||= 'и др.';
  $self->{LANGTEXT}{ru}{editors}{full} ||= 'редакторы';
  $self->{LANGTEXT}{ru}{editors}{abbr} ||= 'ред.';
  $self->{LANGTEXT}{ru}{editor}{full} ||= 'редактор';
  $self->{LANGTEXT}{ru}{editor}{abbr} ||= 'ред.';
  $self->{LANGTEXT}{ru}{edby} ||= 'под ред.';
  $self->{LANGTEXT}{ru}{edition}{full} ||= 'издание';
  $self->{LANGTEXT}{ru}{edition}{abbr} ||= 'изд.';
  $self->{LANGTEXT}{ru}{volume}{full} ||= 'том';
  $self->{LANGTEXT}{ru}{volume}{abbr} ||= 'т.';
  $self->{LANGTEXT}{ru}{of} ||= 'из';
  $self->{LANGTEXT}{ru}{number}{full} ||= 'номер';
  $self->{LANGTEXT}{ru}{number}{abbr} ||= 'номер';
  $self->{LANGTEXT}{ru}{nr} ||= '№';
  $self->{LANGTEXT}{ru}{in} ||= 'в';
  $self->{LANGTEXT}{ru}{pages}{full} ||= 'страницы';
  $self->{LANGTEXT}{ru}{pages}{abbr} ||= 'с.';
  $self->{LANGTEXT}{ru}{page}{full} ||= 'страница';
  $self->{LANGTEXT}{ru}{page}{abbr} ||= 'с.';
  $self->{LANGTEXT}{ru}{eidpp} ||= 'страницы';
  $self->{LANGTEXT}{ru}{chapter}{full} ||= 'глава';
  $self->{LANGTEXT}{ru}{chapter}{abbr} ||= 'гл.';
  #$self->{LANGTEXT}{ru}{techrep}{full} ||= '???';
  #$self->{LANGTEXT}{ru}{techrep}{abbr} ||= '???';
  $self->{LANGTEXT}{ru}{mthesis} ||= 'магистерская работа';
  $self->{LANGTEXT}{ru}{phdthesis} ||= 'докторская диссертация';
  $self->{LANGTEXT}{ru}{edno}{1}{full} ||= 'первое';
  $self->{LANGTEXT}{ru}{edno}{1}{abbr} ||= '1-ое';
  $self->{LANGTEXT}{ru}{edno}{2}{full} ||= 'второе';
  $self->{LANGTEXT}{ru}{edno}{2}{abbr} ||= '2-ое';
  $self->{LANGTEXT}{ru}{edno}{3}{full} ||= 'третее';
  $self->{LANGTEXT}{ru}{edno}{3}{abbr} ||= '3-ее';
  $self->{LANGTEXT}{ru}{edno}{4}{full} ||= 'четвертое';
  $self->{LANGTEXT}{ru}{edno}{4}{abbr} ||= '4-ое';
  $self->{LANGTEXT}{ru}{edno}{5}{full} ||= 'пятое';
  $self->{LANGTEXT}{ru}{edno}{5}{abbr} ||= '5-ое';
  $self->{LANGTEXT}{ru}{th} ||= '-ое';
  $self->{LANGTEXT}{ru}{month1}{full} ||= 'январь';
  $self->{LANGTEXT}{ru}{month2}{full} ||= 'февраль';
  $self->{LANGTEXT}{ru}{month3}{full} ||= 'март';
  $self->{LANGTEXT}{ru}{month4}{full} ||= 'апрель';
  $self->{LANGTEXT}{ru}{month5}{full} ||= 'май';
  $self->{LANGTEXT}{ru}{month6}{full} ||= 'июнь';
  $self->{LANGTEXT}{ru}{month7}{full} ||= 'июль';
  $self->{LANGTEXT}{ru}{month8}{full} ||= 'август';
  $self->{LANGTEXT}{ru}{month9}{full} ||= 'сентябрь';
  $self->{LANGTEXT}{ru}{month10}{full} ||= 'октябрь';
  $self->{LANGTEXT}{ru}{month11}{full} ||= 'ноябрь';
  $self->{LANGTEXT}{ru}{month12}{full} ||= 'декабрь';
  $self->{LANGTEXT}{ru}{month1}{abbr} ||= 'янв.';
  $self->{LANGTEXT}{ru}{month2}{abbr} ||= 'февр.';
  $self->{LANGTEXT}{ru}{month3}{abbr} ||= 'март';
  $self->{LANGTEXT}{ru}{month4}{abbr} ||= 'апр.';
  $self->{LANGTEXT}{ru}{month5}{abbr} ||= 'май';
  $self->{LANGTEXT}{ru}{month6}{abbr} ||= 'июнь';
  $self->{LANGTEXT}{ru}{month7}{abbr} ||= 'июль';
  $self->{LANGTEXT}{ru}{month8}{abbr} ||= 'авг.';
  $self->{LANGTEXT}{ru}{month9}{abbr} ||= 'сент.';
  $self->{LANGTEXT}{ru}{month10}{abbr} ||= 'окт.';
  $self->{LANGTEXT}{ru}{month11}{abbr} ||= 'ноябр.';
  $self->{LANGTEXT}{ru}{month12}{abbr} ||= 'дек.';

  $self->{LANGINIT}{ru} = 1;
}

1;
__END__

=head1 NAME

Bibulus::Lang::ru - Bibulus support for Russian

=head2 EXPORT

None.

=head1 SEE ALSO

F<Bibulus>, F<Bibulus::lang>.

The homepage is
L<http://www.nongnu.org/bibulus/>.

=head1 AUTHOR

Marius L. Jøhndal, L<mariuslj@cpan.org>

=head1 COPYRIGHT AND LICENSE

Copyright 2003 by Marius L. Jøhndal

This module is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
USA.

=cut
